import { ComponentProps, HTMLAttributes, ReactNode } from "react";
export interface DialogProps extends HTMLAttributes<HTMLDivElement> {
    children?: React.ReactNode;
    open?: boolean;
    defaultOpen?: boolean;
    onOpenChange?(open: boolean): void;
    modal?: boolean;
}
export interface DialogContentProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * Used to force mounting when more control is needed. Useful when
     * controlling animation with React animation libraries.
     */
    forceMount?: true;
    children?: ReactNode;
    onEscapeKeyDown?: (event: KeyboardEvent) => void;
    onPointerDownOutside?: (event: PointerDownOutsideEvent) => void;
    /**
     * When `true`, focus cannot escape the `Content` via keyboard,
     * pointer, or a programmatic focus.
     * @defaultValue false
     */
    trapFocus?: FocusScopeProps["trapped"];
    /**
     * Event handler called when auto-focusing on open.
     * Can be prevented.
     */
    onOpenAutoFocus?: FocusScopeProps["onMountAutoFocus"];
    /**
     * Event handler called when auto-focusing on close.
     * Can be prevented.
     */
    onCloseAutoFocus?: FocusScopeProps["onUnmountAutoFocus"];
}
export interface DialogHeaderProps extends HTMLAttributes<HTMLDivElement> {
    children?: ReactNode;
}
export interface DialogFooterProps extends HTMLAttributes<HTMLDivElement> {
    children?: ReactNode;
}
export interface DialogTitleProps extends HTMLAttributes<HTMLHeadingElement> {
    children?: ReactNode;
}
export interface DialogDescriptionProps extends HTMLAttributes<HTMLParagraphElement> {
    children?: ReactNode;
}
export interface DialogOverlayProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * Used to force mounting when more control is needed. Useful when
     * controlling animation with React animation libraries.
     */
    forceMount?: true;
    children?: ReactNode;
}
export interface DialogPortalProps extends HTMLAttributes<HTMLDivElement> {
    children?: React.ReactNode;
    /**
     * Specify a container element to portal the content into.
     */
    container?: Element | DocumentFragment | null;
    /**
     * Used to force mounting when more control is needed. Useful when
     * controlling animation with React animation libraries.
     */
    forceMount?: true;
}
export interface DialogTriggerProps extends HTMLAttributes<HTMLButtonElement> {
    children?: ReactNode;
    asChild?: boolean;
}
export interface DialogCloseProps extends ComponentProps<"button"> {
    children?: ReactNode;
    asChild?: boolean;
}
interface FocusScopeProps {
    /**
     * When `true`, tabbing from last item will focus first tabbable
     * and shift+tab from first item will focus last tababble.
     * @defaultValue false
     */
    loop?: boolean;
    /**
     * When `true`, focus cannot escape the focus scope via keyboard,
     * pointer, or a programmatic focus.
     * @defaultValue false
     */
    trapped?: boolean;
    /**
     * Event handler called when auto-focusing on mount.
     * Can be prevented.
     */
    onMountAutoFocus?: (event: Event) => void;
    /**
     * Event handler called when auto-focusing on unmount.
     * Can be prevented.
     */
    onUnmountAutoFocus?: (event: Event) => void;
}
type PointerDownOutsideEvent = CustomEvent<{
    originalEvent: PointerEvent;
}>;
export {};
